import * as fs from 'fs';
import * as os from 'os';
import { join } from 'path';
const SEVERITY = {
    ERROR: 'ERROR',
    WARNING: 'WARNING',
    INFO: 'INFO',
    DEBUG: 'DEBUG',
};
export class Logger {
    constructor() {
        const dir = join(os.tmpdir(), 'graphql-language-service-logs');
        try {
            if (!fs.existsSync(dir)) {
                fs.mkdirSync(dir);
            }
        }
        catch (_) {
        }
        this._logFilePath = join(dir, `graphql-language-service-log-${os.userInfo().username}-${getDateString()}.log`);
        this._stream = null;
    }
    error(message) {
        this._log(message, 'ERROR');
    }
    warn(message) {
        this._log(message, 'WARNING');
    }
    info(message) {
        this._log(message, 'INFO');
    }
    log(message) {
        this._log(message, 'DEBUG');
    }
    _log(message, severityKey = 'DEBUG') {
        const timestamp = new Date().toLocaleString(undefined);
        const severity = SEVERITY[severityKey];
        const pid = process.pid;
        const logMessage = `${timestamp} [${severity}] (pid: ${pid}) graphql-language-service-usage-logs: ${message}\n\n`;
        fs.appendFile(this._logFilePath, logMessage, _error => { });
        process.stderr.write(logMessage, _err => {
        });
    }
}
function getDateString() {
    const date = new Date();
    return `${date.getFullYear()}-${date.getMonth() + 1}-${date.getDate()}`;
}
//# sourceMappingURL=Logger.js.map